@@ -1,16 +1,14 @@
-from coords_transformer.constants import ZOOM, PIXEL_SIZE
 from coords_transformer.filename.filename import FileName
 import re
 
 
-def create_from_filename(filename: str, path: str, size: int = PIXEL_SIZE):
+def create_from_filename(filename: str, path: str):
 	"""
 	Args:
-		filename: name of file which is in designated format.
+		filename: name of file in the designated format.
 		path: path to file
-		size: image file pixel size
 	Returns:
-		a Filename object
+		Filename object
 	"""
 	dot_converted_filename = filename.replace('dot', '.')
 	idx = int(re.search(r'^([\d\.]*)_long', dot_converted_filename).group(1))
