@@ -5,13 +5,13 @@ from .point import Point
 def create_point_from_image_pixel_coords(x_distance: int, y_distance: int, ctr_pt: Point, size: int, zoom: int) -> Point:
     """
     Args:
-        x_distance: x pixel coordinate within an image.
-        y_distance: y pixel coordinate within an image.
-        ctr_pt: a Point object of the center point in an image.
+        x_distance: x pixel coordinate within the satellite image.
+        y_distance: y pixel coordinate within the satellite image.
+        ctr_pt: the Point object of the center point of the image.
         size: pixel image size.
-        zoom: zoom level of an image.
+        zoom: zoom level of the image.
     Returns:
-        a Point object
+        Point object
     """
     diff = int(size / 2)
     origin_x = ctr_pt.x - diff
